@@ -7,7 +7,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                   unitName = "pounds/day",
                                   unitExpress = expression("Flux in pounds/day"),
                                   unitExpressTiny = expression("Flux (lbs/d)"),
-                                  unitEstimate = expression("Estimated flux in pounds/day"),
+                                  unitEstimate = expression("flux in pounds/day"),
                                   unitEstimateTiny = expression("Est. flux (lbs/d)"),
                                   unitUSGS = "Flux, in pounds per day",
                                   shortCode = 1),
@@ -17,7 +17,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                 unitName = "tons/day",
                                 unitExpress = expression("Flux in tons/day"),
                                 unitExpressTiny = expression("Flux (tons/d)"),
-                                unitEstimate = expression("Estimated flux in tons/day"),
+                                unitEstimate = expression("flux in tons/day"),
                                 unitEstimateTiny = expression("Est. flux (tons/d)"),
                                 unitUSGS = "Flux, in tons per day",
                                 shortCode = 2),
@@ -27,7 +27,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                               unitName = "kg/day",
                               unitExpress = expression("Flux in kg/day"),
                               unitExpressTiny = expression("Flux (kg/d)"),
-                              unitEstimate = expression("Estimated flux in kg/day"),
+                              unitEstimate = expression("flux in kg/day"),
                               unitEstimateTiny = expression("Est. flux (kg/d)"),
                               unitUSGS = "Flux, in kilograms per day",
                               shortCode = 3),
@@ -37,7 +37,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitName = "thousands of kg/day",
                                       unitExpress = expression(paste("Flux in ",10^3*kg/day)),
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^3*kg/d, ")")),
-                                      unitEstimate = expression(paste("Estimated flux in ",10^3*kg/day)),
+                                      unitEstimate = expression(paste("flux in ",10^3*kg/day)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*kg/d, ")")),
                                       unitUSGS = "Flux, in thousands of kilograms per day",
                                       shortCode = 4),
@@ -47,7 +47,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                  unitName = "tons/year",
                                  unitExpress = expression("Flux in tons/year"),
                                  unitExpressTiny = expression("Flux (tons/yr)"),
-                                 unitEstimate = expression("Estimated flux in tons/year"),
+                                 unitEstimate = expression("flux in tons/year"),
                                  unitEstimateTiny = expression("Est. flux (tons/yr)"),
                                  unitUSGS = "Flux, in tons per year",
                                  shortCode = 5),
@@ -57,7 +57,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                          unitName = "thousands of tons/year",
                                          unitExpress = expression(paste("Flux in ",10^3*tons/yr)),
                                          unitExpressTiny = expression(paste("Flux ", "(", 10^3*tons/yr, ")")),
-                                         unitEstimate = expression(paste("Estimated flux in ",10^3*tons/yr)),
+                                         unitEstimate = expression(paste("flux in ",10^3*tons/yr)),
                                          unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*tons/yr, ")")),
                                          unitUSGS = "Flux, in thousands of tons per year",
                                          shortCode = 6),
@@ -67,7 +67,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                         unitName = "millions of tons/year",
                                         unitExpress = expression(paste("Flux in ",10^6*tons/yr)),
                                         unitExpressTiny = expression(paste("Flux ", "(", 10^6*tons/yr, ")")),
-                                        unitEstimate = expression(paste("Estimated flux in ",10^6*tons/yr)),
+                                        unitEstimate = expression(paste("flux in ",10^6*tons/yr)),
                                         unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*tons/yr, ")")),
                                         unitUSGS = "Flux, in millions of tons per year",
                                         shortCode = 7),
@@ -77,7 +77,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                        unitName = "thousands of kg/year",
                                        unitExpress = expression(paste("Flux in ",10^3*kg/yr)),
                                        unitExpressTiny = expression(paste("Flux ", "(", 10^3*kg/yr, ")")),
-                                       unitEstimate = expression(paste("Estimated flux in ",10^3*kg/yr)),
+                                       unitEstimate = expression(paste("flux in ",10^3*kg/yr)),
                                        unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*kg/yr, ")")),
                                        unitUSGS = "Flux, in thousands of kilograms per year",
                                        shortCode = 8),
@@ -87,7 +87,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitName = "millions of kg/year",
                                       unitExpress = expression(paste("Flux in ",10^6*kg/yr)),
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^6*kg/yr, ")")),
-                                      unitEstimate = expression(paste("Estimated flux in ",10^6*kg/yr)),
+                                      unitEstimate = expression(paste("flux in ",10^6*kg/yr)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*kg/yr, ")")),
                                       unitUSGS = "Flux, in millions of kilograms per year",
                                       shortCode = 9),
@@ -97,7 +97,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitName = "billions of kg/year",
                                       unitExpress = expression(paste("Flux in",10^9*kg/yr)),
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^9*kg/yr, ")")),
-                                      unitEstimate = expression(paste("Estimated flux in",10^9*kg/yr)),
+                                      unitEstimate = expression(paste("flux in",10^9*kg/yr)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^9*kg/yr, ")")),
                                       unitUSGS = "Flux, in billions of kilograms per year",
                                       shortCode = 10),
@@ -107,7 +107,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                         unitName = "thousands of tons/day",
                                         unitExpress = expression(paste("Flux in ",10^3*tons/day)),
                                         unitExpressTiny = expression(paste("Flux ", "(", 10^3*tons/d, ")")),
-                                        unitEstimate = expression(paste("Estimated flux in ",10^3*tons/day)),
+                                        unitEstimate = expression(paste("flux in ",10^3*tons/day)),
                                         unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*tons/d, ")")),
                                         unitUSGS = "Flux, in thousands of tons per day",
                                         shortCode = 11),
@@ -117,7 +117,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                      unitName = "millions of kg/day",
                                      unitExpress = expression(paste("Flux in ",10^6*kg/day)),
                                      unitExpressTiny = expression(paste("Flux ", "(", 10^6*kg/d, ")")),
-                                     unitEstimate = expression(paste("Estimated flux in ",10^6*kg/day)),
+                                     unitEstimate = expression(paste("flux in ",10^6*kg/day)),
                                      unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*kg/d, ")")),
                                      unitUSGS = "Flux, in millions of kilograms per day",
                                      shortCode = 12),
@@ -127,7 +127,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                      unitName = "kg/year",
                                      unitExpress = expression("Flux in kg/year"),
                                      unitExpressTiny = expression("Flux (kg/yr)"),
-                                     unitEstimate = expression("Estimated flux in kg/year"),
+                                     unitEstimate = expression("flux in kg/year"),
                                      unitEstimateTiny = expression("Est. flux in kg/yr"),
                                      unitUSGS = "Flux, in kilograms per year",
                                      shortCode = 13)
