@@ -7,7 +7,7 @@ test_that("calculateMonthly returns expected type/format", {
   expect_is(results$Q, "numeric")
   expect_true(all(names(results) %in% c("Month", "Year", "DecYear", "Q",          
                                  "Conc", "Flux", "FNConc",     
-                                 "FNFlux")))
+                                 "FNFlux", "nDays")))
 })
 
 test_that("flowDuration returns expected type, and arguments change output", {
